@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-plugins-engine.h 6045 2007-12-28 20:45:22Z sfre $
+ * $Id: gedit-plugins-engine.h 6619 2008-11-25 22:00:16Z jessevdk $
  */
 
 #ifndef __GEDIT_PLUGINS_ENGINE_H__
@@ -75,6 +75,11 @@ void		 gedit_plugins_engine_garbage_collect	(GeditPluginsEngine *engine);
 
 const GList	*gedit_plugins_engine_get_plugin_list 	(GeditPluginsEngine *engine);
 
+GeditPluginInfo	*gedit_plugins_engine_get_plugin_info	(GeditPluginsEngine *engine,
+							 const gchar        *name);
+
+
+/* plugin load and unloading (overall, for all windows) */
 gboolean 	 gedit_plugins_engine_activate_plugin 	(GeditPluginsEngine *engine,
 							 GeditPluginInfo    *info);
 gboolean 	 gedit_plugins_engine_deactivate_plugin	(GeditPluginsEngine *engine,
@@ -84,13 +89,13 @@ void	 	 gedit_plugins_engine_configure_plugin	(GeditPluginsEngine *engine,
 							 GeditPluginInfo    *info,
 							 GtkWindow          *parent);
 
-/* 
- * new_window == TRUE if this function is called because a new top window
- * has been created
- */
-void		 gedit_plugins_engine_update_plugins_ui (GeditPluginsEngine *engine,
-							 GeditWindow        *window, 
-							 gboolean            new_window);
+/* plugin activation/deactivation per window, private to GeditWindow */
+void 		 gedit_plugins_engine_activate_plugins   (GeditPluginsEngine *engine,
+							  GeditWindow        *window);
+void 		 gedit_plugins_engine_deactivate_plugins (GeditPluginsEngine *engine,
+							  GeditWindow        *window);
+void		 gedit_plugins_engine_update_plugins_ui  (GeditPluginsEngine *engine,
+							  GeditWindow        *window);
 
 G_END_DECLS
 
