@@ -31,10 +31,7 @@
 #endif
 
 #include <glib/gi18n.h>
-
-#include <libgnomeui/libgnomeui.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gio/gio.h>
 
 #include "gedit-app.h"
 #include "gedit-notebook.h"
@@ -753,7 +750,7 @@ show_saving_message_area (GeditTab *tab)
 
 		from = short_name;
 
-		to = gedit_utils_format_uri_for_display (tab->priv->tmp_save_uri);
+		to = gedit_utils_uri_for_display (tab->priv->tmp_save_uri);
 
 		str = gedit_utils_str_middle_truncate (to, 
 						       MAX (20, MAX_MSG_LENGTH - len));
@@ -795,9 +792,9 @@ show_saving_message_area (GeditTab *tab)
 }
 
 static void
-message_area_set_progress (GeditTab	    *tab,
-			   GnomeVFSFileSize  size,
-			   GnomeVFSFileSize  total_size)
+message_area_set_progress (GeditTab *tab,
+			   goffset   size,
+			   goffset   total_size)
 {
 	if (tab->priv->message_area == NULL)
 		return;
@@ -829,10 +826,10 @@ message_area_set_progress (GeditTab	    *tab,
 }
 
 static void
-document_loading (GeditDocument    *document,
-		  GnomeVFSFileSize  size,
-		  GnomeVFSFileSize  total_size,
-		  GeditTab         *tab)
+document_loading (GeditDocument *document,
+		  goffset        size,
+		  goffset        total_size,
+		  GeditTab      *tab)
 {
 	double et;
 
@@ -898,6 +895,7 @@ document_loaded (GeditDocument *document,
 		 GeditTab      *tab)
 {
 	GtkWidget *emsg;
+	GFile *location;
 	gchar *uri;
 	const GeditEncoding *encoding;
 
@@ -914,6 +912,7 @@ document_loaded (GeditDocument *document,
 
 	set_message_area (tab, NULL);
 
+	location = gedit_document_get_location (document);
 	uri = gedit_document_get_uri (document);
 
 	if (error != NULL)
@@ -925,52 +924,51 @@ document_loaded (GeditDocument *document,
 
 		encoding = gedit_document_get_encoding (document);
 
-		if (error->domain == GEDIT_DOCUMENT_ERROR)
+		if (error->domain == G_IO_ERROR && 
+		    error->code == G_IO_ERROR_CANCELLED)
 		{
-			if (error->code == GNOME_VFS_ERROR_CANCELLED)
-			{
-				/* remove the tab, but in an idle handler, since
-				 * we are in the handler of doc loaded and we 
-				 * don't want doc and tab to be finalized now.
-				 */
-				g_idle_add ((GSourceFunc) remove_tab_idle, tab);
+			/* remove the tab, but in an idle handler, since
+			 * we are in the handler of doc loaded and we 
+			 * don't want doc and tab to be finalized now.
+			 */
+			g_idle_add ((GSourceFunc) remove_tab_idle, tab);
 
-				goto end;
+			goto end;
+		}
+		else if (error->domain == G_IO_ERROR || 
+			 error->domain == GEDIT_DOCUMENT_ERROR)
+		{
+			_gedit_recent_remove (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))), uri);
+
+			if (tab->priv->state == GEDIT_TAB_STATE_LOADING_ERROR)
+			{
+				emsg = gedit_io_loading_error_message_area_new (uri, 
+										error);
+				g_signal_connect (emsg,
+						  "response",
+						  G_CALLBACK (io_loading_error_message_area_response),
+						  tab);
 			}
 			else
 			{
-				_gedit_recent_remove (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))), uri);
+				g_return_if_fail (tab->priv->state == GEDIT_TAB_STATE_REVERTING_ERROR);
+				
+				emsg = gedit_unrecoverable_reverting_error_message_area_new (uri, 
+											     error);
 
-				if (tab->priv->state == GEDIT_TAB_STATE_LOADING_ERROR)
-				{
-					emsg = gedit_io_loading_error_message_area_new (uri, 
-											error);
-					g_signal_connect (emsg,
-							  "response",
-							  G_CALLBACK (io_loading_error_message_area_response),
-							  tab);
-				}
-				else
-				{
-					g_return_if_fail (tab->priv->state == GEDIT_TAB_STATE_REVERTING_ERROR);
-					
-					emsg = gedit_unrecoverable_reverting_error_message_area_new (uri, 
-												     error);
-
-					g_signal_connect (emsg,
-							  "response",
-							  G_CALLBACK (unrecoverable_reverting_error_message_area_response),
-							  tab);
-				}
-
-				set_message_area (tab, emsg);
+				g_signal_connect (emsg,
+						  "response",
+						  G_CALLBACK (unrecoverable_reverting_error_message_area_response),
+						  tab);
 			}
+
+			set_message_area (tab, emsg);
 		}
 		else
 		{
 			g_return_if_fail ((error->domain == G_CONVERT_ERROR) ||
 			      		  (error->domain == GEDIT_CONVERT_ERROR));
-			
+
 			// TODO: different error messages if tab->priv->state == GEDIT_TAB_STATE_REVERTING?
 			// note that while reverting encoding should be ok, so this is unlikely to happen
 			emsg = gedit_conversion_error_while_loading_message_area_new (
@@ -990,6 +988,8 @@ document_loaded (GeditDocument *document,
 							 GTK_RESPONSE_CANCEL);
 
 		gtk_widget_show (emsg);
+
+		g_object_unref (location);
 		g_free (uri);
 
 		return;
@@ -1016,12 +1016,12 @@ document_loaded (GeditDocument *document,
 			
 			if (d != document)
 			{
-				gchar *u;
+				GFile *loc;
 
-				u = gedit_document_get_uri (d);
+				loc = gedit_document_get_location (d);
 
-				if ((u != NULL) &&
-			    	    gnome_vfs_uris_match (uri, u))
+				if ((loc != NULL) &&
+			    	    g_file_equal (location, loc))
 			    	{
 			    		GtkWidget *w;
 			    		GeditView *view;
@@ -1044,12 +1044,12 @@ document_loaded (GeditDocument *document,
 							  G_CALLBACK (file_already_open_warning_message_area_response),
 							  tab);
 
-					g_free (u);
-
+			    		g_object_unref (loc);
 			    		break;
 			    	}
-
-				g_free (u);
+			    	
+			    	if (loc != NULL)
+					g_object_unref (loc);
 			}
 		}
 
@@ -1063,6 +1063,7 @@ document_loaded (GeditDocument *document,
 	}
 
  end:
+	g_object_unref (location);
 	g_free (uri);
 
 	tab->priv->tmp_line_pos = 0;
@@ -1071,8 +1072,8 @@ document_loaded (GeditDocument *document,
 
 static void
 document_saving (GeditDocument    *document,
-		 GnomeVFSFileSize  size,
-		 GnomeVFSFileSize  total_size,
+		 goffset  size,
+		 goffset  total_size,
 		 GeditTab         *tab)
 {
 	double et;
@@ -1292,55 +1293,55 @@ document_saved (GeditDocument *document,
 	{
 		gedit_tab_set_state (tab, GEDIT_TAB_STATE_SAVING_ERROR);
 		
-		if (error->domain == GEDIT_DOCUMENT_ERROR)
+		if (error->domain == GEDIT_DOCUMENT_ERROR &&
+		    error->code == GEDIT_DOCUMENT_ERROR_EXTERNALLY_MODIFIED)
 		{
-			if (error->code == GEDIT_DOCUMENT_ERROR_EXTERNALLY_MODIFIED)
-			{
-				/* This error is recoverable */
-				emsg = gedit_externally_modified_saving_error_message_area_new (
-								tab->priv->tmp_save_uri, 
-								error);
-				g_return_if_fail (emsg != NULL);
+			/* This error is recoverable */
+			emsg = gedit_externally_modified_saving_error_message_area_new (
+							tab->priv->tmp_save_uri, 
+							error);
+			g_return_if_fail (emsg != NULL);
 
-				set_message_area (tab, emsg);
+			set_message_area (tab, emsg);
 
-				g_signal_connect (emsg,
-						  "response",
-						  G_CALLBACK (externally_modified_error_message_area_response),
-						  tab);
-			}
-			else if (error->code == GEDIT_DOCUMENT_ERROR_CANT_CREATE_BACKUP)
-			{
-				/* This error is recoverable */
-				emsg = gedit_no_backup_saving_error_message_area_new (
-								tab->priv->tmp_save_uri, 
-								error);
-				g_return_if_fail (emsg != NULL);
+			g_signal_connect (emsg,
+					  "response",
+					  G_CALLBACK (externally_modified_error_message_area_response),
+					  tab);
+		}
+		else if (error->domain == GEDIT_DOCUMENT_ERROR &&
+			 error->code == GEDIT_DOCUMENT_ERROR_CANT_CREATE_BACKUP)
+		{
+			/* This error is recoverable */
+			emsg = gedit_no_backup_saving_error_message_area_new (
+							tab->priv->tmp_save_uri, 
+							error);
+			g_return_if_fail (emsg != NULL);
 
-				set_message_area (tab, emsg);
+			set_message_area (tab, emsg);
 
-				g_signal_connect (emsg,
-						  "response",
-						  G_CALLBACK (no_backup_error_message_area_response),
-						  tab);
-			}
-			else
-			{
-				/* These errors are _NOT_ recoverable */
-				_gedit_recent_remove  (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))),
-						       tab->priv->tmp_save_uri);
+			g_signal_connect (emsg,
+					  "response",
+					  G_CALLBACK (no_backup_error_message_area_response),
+					  tab);
+		}
+		else if (error->domain == GEDIT_DOCUMENT_ERROR || 
+			 error->domain == G_IO_ERROR)
+		{
+			/* These errors are _NOT_ recoverable */
+			_gedit_recent_remove  (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))),
+					       tab->priv->tmp_save_uri);
 
-				emsg = gedit_unrecoverable_saving_error_message_area_new (tab->priv->tmp_save_uri, 
-									  error);
-				g_return_if_fail (emsg != NULL);
-		
-				set_message_area (tab, emsg);
+			emsg = gedit_unrecoverable_saving_error_message_area_new (tab->priv->tmp_save_uri, 
+								  error);
+			g_return_if_fail (emsg != NULL);
+	
+			set_message_area (tab, emsg);
 
-				g_signal_connect (emsg,
-						  "response",
-						  G_CALLBACK (unrecoverable_saving_error_message_area_response),
-						  tab);
-			}			
+			g_signal_connect (emsg,
+					  "response",
+					  G_CALLBACK (unrecoverable_saving_error_message_area_response),
+					  tab);
 		}
 		else
 		{
@@ -1364,7 +1365,6 @@ document_saved (GeditDocument *document,
 							 GTK_RESPONSE_CANCEL);
 
 		gtk_widget_show (emsg);
-		
 	}
 	else
 	{
@@ -1482,6 +1482,17 @@ view_focused_in (GtkWidget     *widget,
 	return FALSE;
 }
 
+static GMountOperation *
+tab_mount_operation_factory (GeditDocument *doc,
+			     gpointer userdata)
+{
+	GeditTab *tab = GEDIT_TAB (userdata);
+	GtkWidget *window;
+
+	window = gtk_widget_get_toplevel (GTK_WIDGET (tab));
+	return gtk_mount_operation_new (GTK_WINDOW (window));
+}
+
 static void
 gedit_tab_init (GeditTab *tab)
 {
@@ -1521,6 +1532,10 @@ gedit_tab_init (GeditTab *tab)
 	doc = gedit_document_new ();
 	g_object_set_data (G_OBJECT (doc), GEDIT_TAB_KEY, tab);
 
+	_gedit_document_set_mount_operation_factory (doc,
+						     tab_mount_operation_factory,
+						     tab);
+
 	tab->priv->view = gedit_view_new (doc);
 	g_object_unref (doc);
 	gtk_widget_show (tab->priv->view);
@@ -1664,11 +1679,6 @@ _gedit_tab_get_tooltips	(GeditTab *tab)
 	gchar *uri;
 	gchar *ruri;
 	gchar *ruri_markup;
-	gchar *mime_type;
-	const gchar *mime_description = NULL;
-	gchar *mime_full_description; 
-	gchar *encoding;
-	const GeditEncoding *enc;
 
 	g_return_val_if_fail (GEDIT_IS_TAB (tab), NULL);
 
@@ -1684,6 +1694,12 @@ _gedit_tab_get_tooltips	(GeditTab *tab)
 
 	switch (tab->priv->state)
 	{
+		gchar *mime_type;
+		gchar *mime_description;
+		gchar *mime_full_description; 
+		gchar *encoding;
+		const GeditEncoding *enc;
+
 		case GEDIT_TAB_STATE_LOADING_ERROR:
 			tip = g_strdup_printf (_("Error opening file %s"),
 					       ruri_markup);
@@ -1700,7 +1716,7 @@ _gedit_tab_get_tooltips	(GeditTab *tab)
 			break;			
 		default:
 			mime_type = gedit_document_get_mime_type (doc);
-			mime_description = gnome_vfs_mime_get_description (mime_type);
+			mime_description = g_content_type_get_description (mime_type);
 
 			if (mime_description == NULL)
 				mime_full_description = g_strdup (mime_type);
@@ -1708,6 +1724,7 @@ _gedit_tab_get_tooltips	(GeditTab *tab)
 				mime_full_description = g_strdup_printf ("%s (%s)", 
 						mime_description, mime_type);
 
+			g_free (mime_description);
 			g_free (mime_type);
 
 			enc = gedit_document_get_encoding (doc);
@@ -1726,7 +1743,7 @@ _gedit_tab_get_tooltips	(GeditTab *tab)
 
 			g_free (encoding);
 			g_free (mime_full_description);
-			
+
 			break;
 	}
 	
@@ -1768,33 +1785,10 @@ resize_icon (GdkPixbuf *pixbuf,
 		g_object_unref (pixbuf);
 		pixbuf = scaled_pixbuf;
 	}
-	
+
 	return pixbuf;
 }
 
-static GdkPixbuf *
-get_icon (GtkIconTheme *theme, 
-	  const gchar  *uri,
-	  const gchar  *mime_type, 
-	  gint          size)
-{
-	gchar *icon;
-	GdkPixbuf *pixbuf;
-	
-	icon = gnome_icon_lookup (theme, NULL, uri, NULL, NULL,
-				  mime_type, 0, NULL);
-	
-
-	g_return_val_if_fail (icon != NULL, NULL);
-
-	pixbuf = gtk_icon_theme_load_icon (theme, icon, size, 0, NULL);
-	g_free (icon);
-	if (pixbuf == NULL)
-		return NULL;
-		
-	return resize_icon (pixbuf, size);
-}
-
 static GdkPixbuf *
 get_stock_icon (GtkIconTheme *theme, 
 		const gchar  *stock,
@@ -1809,6 +1803,51 @@ get_stock_icon (GtkIconTheme *theme,
 	return resize_icon (pixbuf, size);
 }
 
+static GdkPixbuf *
+get_icon (GtkIconTheme *theme, 
+	  GFile        *location,
+	  gint          size)
+{
+	GdkPixbuf *pixbuf;
+	GtkIconInfo *icon_info;
+	GFileInfo *info;
+	GIcon *gicon;
+
+	if (location == NULL)
+		return get_stock_icon (theme, GTK_STOCK_FILE, size);
+
+	/* FIXME: Doing a sync stat is bad, this should be fixed */
+	info = g_file_query_info (location, 
+	                          G_FILE_ATTRIBUTE_STANDARD_ICON, 
+	                          G_FILE_QUERY_INFO_NONE, 
+	                          NULL, 
+	                          NULL);
+	if (info == NULL)
+		return get_stock_icon (theme, GTK_STOCK_FILE, size);
+
+	gicon = g_file_info_get_icon (info);
+
+	if (gicon == NULL)
+	{
+		g_object_unref (info);
+		return get_stock_icon (theme, GTK_STOCK_FILE, size);
+	}
+
+	icon_info = gtk_icon_theme_lookup_by_gicon (theme, gicon, size, 0);
+	g_object_unref (info);	
+	
+	if (icon_info == NULL)
+		return get_stock_icon (theme, GTK_STOCK_FILE, size);
+	
+	pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
+	gtk_icon_info_free (icon_info);
+	
+	if (pixbuf == NULL)
+		return get_stock_icon (theme, GTK_STOCK_FILE, size);
+		
+	return resize_icon (pixbuf, size);
+}
+
 /* FIXME: add support for theme changed. I think it should be as easy as
    call g_object_notify (tab, "name") when the icon theme changes */
 GdkPixbuf *
@@ -1881,19 +1920,16 @@ _gedit_tab_get_icon (GeditTab *tab)
 
 		default:
 		{
-			gchar *raw_uri;
-			gchar *mime_type;
+			GFile *location;
 			GeditDocument *doc;
 
 			doc = gedit_tab_get_document (tab);
 
-			raw_uri = gedit_document_get_uri (doc);
-			mime_type = gedit_document_get_mime_type (doc);
+			location = gedit_document_get_location (doc);
+			pixbuf = get_icon (theme, location, icon_size);
 
-			pixbuf = get_icon (theme, raw_uri, mime_type, icon_size);
-
-			g_free (raw_uri);
-			g_free (mime_type);
+			if (location)
+				g_object_unref (location);
 		}
 	}
 
